import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:chessboard_js/chessboard_js.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';

void main() {
  runApp(ProviderScope(child: MyApp()));
}

class MyApp extends StatelessWidget {
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: ChessGame(),
    );
  }
}

final moveProvider = StateProvider<String>((ref) => '');

class ChessGame extends HookConsumerWidget {
  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final ChessboardController controller =
        ChessboardController(onMove: (move) {
//      print('move: $move');
    });

    return Scaffold(
      backgroundColor: Colors.black,
      body: SizedBox.expand(
        child: Theme(
          data: ThemeData.dark(),
          child: Container(
            child: Row(
              mainAxisSize: MainAxisSize.max,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                ChessBoard(
                  initialSize: 500,
                  minSize: 300,
                  controller: controller,
                  showNotationPanel: true,
                  buttons: Row(
                    children: [
                      IconButton(
                          onPressed: () async {
                            bool? didResign = await showDialog(
                                context: context,
                                builder: (context) {
                                  return SimpleDialog(
                                    title: Text('Do you want to resign?'),
                                    children: [
                                      Row(
                                        mainAxisAlignment:
                                            MainAxisAlignment.spaceAround,
                                        children: [
                                          TextButton(
                                              onPressed: () {
                                                Navigator.pop(context, true);
                                              },
                                              child: Text('Yes')),
                                          TextButton(
                                              onPressed: () {
                                                Navigator.pop(context, false);
                                              },
                                              child: Text('No')),
                                        ],
                                      )
                                    ],
                                  );
                                });

                            if (didResign == null) didResign = false;
                            if (didResign) print('resigned');
                            print('didResign: $didResign');
                          },
                          icon: Icon(Icons.flag_rounded))
                    ],
                  ),
                ),

                /// Uncomment to test making move programmatically
//              Column(
//                children: [
//                  Text('Test Moves', style: TextStyle(color: Colors.white)),
//                  Container(
//                    width: 200,
//                    child: TextField(
//                      onChanged: (value) {
//                        context.read(moveProvider).state = value;
//                      },
//                    ),
//                  ),
//                  TextButton(
//                      onPressed: () {
//                        final move = context.read(moveProvider).state;
//                        bool moveMade = controller.makeSanMove(move);
//                        if (!moveMade) {
//                          showDialog(
//                              context: context,
//                              builder: (context) =>
//                                  AlertDialog(title: Text('Illegal Move')));
//                        }
////                        print(controller.getSanHistory());
//                      },
//                      child: Text('Submit')),
//                  TextButton(
//                      onPressed: () {
//                        if (controller.movesEnabled)
//                          controller.disableUserMoves();
//                        else
//                          controller.enableUserMove();
//                      },
//                      child: Text('Enable/Disable Moves')),
//                ],
//              )
              ],
            ),
          ),
        ),
      ),
    );
  }
}
