import 'package:flutter/material.dart';
import 'package:chessjs/chessjs.dart' as chessjs;

/// will be used to handle different lines in a position
/// as a tree-like structure
/// **FOR NOW THERE IS NO SUPPORT FOR LINES
class MoveHistory extends ChangeNotifier {
  MoveHistory();

  /// whole move history
  List<String> _history = [];

  /// moves undone when user when back on the game
  List<chessjs.Move> _undoneMoves = [];

  /// current move display on the board
  int _currentIndex = 0;

  List<String> get history => _history;
  List<chessjs.Move> get undoneMoves => _undoneMoves;
  int get currentIndex => _currentIndex;

  /// add a move to the move history
  void addMoveToHistory(String move) {
    _history.add(move);
    _currentIndex = _currentIndex + 1;
    notifyListeners();
  }

  chessjs.Move? goForwardOneMove() {
    if (undoneMoves.isNotEmpty) {
      _currentIndex = _currentIndex + 1;
      final chessjs.Move move = undoneMoves.removeLast();
      return move;
    } else
      return null;
  }

  /// decrease current index in history and save the undone move
  void goBackOneMove(chessjs.Move undoneMove) {
    if (_history.isNotEmpty) {
      _currentIndex = _currentIndex - 1;
      undoneMoves.add(undoneMove);
    }
  }
}
